@@ -8,7 +8,7 @@ import tensorflow as tf
 from mlphys.deepqis.utils import Extract_Net as arlnet
 
 __author__ = 'Sanjaya Lohani'
-__email__ = 'slohani@mlphys.com'
+__email__ = 'slohani@mlphys_nightly.com'
 __licence__ = 'Apache 2.0'
 __website__ = "sanjayalohani.com"
 
