@@ -9,7 +9,7 @@ It only works for the two qubit case
 import numpy as np
 
 __author__ = 'Sanjaya Lohani'
-__email__ = 'slohani@mlphys.com'
+__email__ = 'slohani@mlphys_nightly.com'
 __licence__ = 'Apache 2.0'
 __website__ = "sanjayalohani.com"
 
