@@ -6,7 +6,7 @@ Licence: Apache-2.0
 import tensorflow as tf
 
 __author__ = 'Sanjaya Lohani'
-__email__ = 'slohani@mlphys.com'
+__email__ = 'slohani@mlphys_nightly.com'
 __licence__ = 'Apache 2.0'
 __website__ = "sanjayalohani.com"
 
